# ATLS/Api
AT-RTS (Remote Translation Service) is the web API which enables our translation systems to be integrated into our clients’ systems, from where the entire content translation process can be controlled.<br/>The web API, based on a SOAP web service, has REST interoperability from version 5.3.0.<br/>The operational functionalities are:<ul><li><b>Operating check:</b> Active service check.</li><li><b>Synchronous translation:</b> requests for automatic translation (non-human) orders.</li><li><b>Asynchronous translation:</b> Asynchronous requests for specialised professional translation orders.<br/>Each request returns a <b><i>token</i></b>, associated with the translation request, the purpose of which is to uniquely identify each work request so that the corresponding translation can be requested in the future once proofreading is complete.<br/>It should be noted that asynchronous translation requests have the option to indicate a <b><i>callback</i></b> URL, which involves activating a completed translation notification service, so that our clients can automate the completed request download process.<br/>To summarise, in this case, AT sends the requests directly to our clients’ systems for them to be located in their systems.<br/>Conceptually, at ATLS Global we guarantee the <b><i>return of translations</i></b> for asynchronous order requests to our clients’ infrastructure, taking into account that if the communication system fails <b><i>repeatedly a certain number of times</i></b> for any reason, a warning email would be sent to the email account that the client has specified during the request.</li><li><b>Translation return request:</b> Request to obtain a professional translation order from a token generated by the asynchronous translation request. If the order is not complete, it returns document status information.</li><li><b>Cancellation of a translation:</b> request for cancellation of previous asynchronous translation requests by token that have not been initiated. In this case, ATLS Global S.L. systems will validate that the indicated token has not started the translation process; if it has not started, the request will be cancelled.</li><li><b>List of requests:</b> Request regarding status and consumption of translation orders from the cut-off date, with the following information:<ul><li>projectid: AT project ID</li><li>token: Request token</li><li>sourcelang: Source language</li><li>targetlang: Target language</li>filename: Name associated with the request</li><li>wordcount: Number of words</li><li>status: Translation status<ul><li>10: Under review</li><li>20: Ready and pending delivery</li><li>30: Delivered</li><li>40: Canceled and deleted</li><li>50: Expired delivery</li><li>90: Documental entry error</li><li>100: Processing error</li></ul></li><li>urlcallback: (optional) completed translation return URL</li><li>errnotifiersendto (optional): translation return error notification email</li><li>dateinsert: Date of registration</li><li>type: Translation type, SYNCHRONOUS OR ASYNCHRONOUS.</li></ul></li></ul>

This PHP package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 5.6.0
- Build package: io.swagger.codegen.v3.generators.php.PhpClientCodegen

## Requirements

PHP 5.5 and later

## Installation & Usage
### Composer

To install the bindings via [Composer](http://getcomposer.org/), add the following to `composer.json`:

```
{
  "repositories": [
    {
      "type": "git",
      "url": "https://github.com/atls/atls/api-client.git"
    }
  ],
  "require": {
    "atls/atls/api-client": "*@dev"
  }
}
```

Then run `composer install`

### Manual Installation

Download the files and include `autoload.php`:

```php
    require_once('/path/to/ATLS/Api/vendor/autoload.php');
```

## Tests

To run the unit tests:

```
composer install
./vendor/bin/phpunit
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: ApiKeyAuth
$config = ATLS\Api\Configuration::getDefaultConfiguration()->setApiKey('X-ATRTS-API-Key', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = ATLS\Api\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-ATRTS-API-Key', 'Bearer');// Configure HTTP basic authorization: BasicAuth
$config = ATLS\Api\Configuration::getDefaultConfiguration()
    ->setUsername('YOUR_USERNAME')
    ->setPassword('YOUR_PASSWORD');

$apiInstance = new ATLS\Api\Api\RestapiApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$body = new \stdClass; // object | Document information to be deleted

try {
    $result = $apiInstance->delFileByToken($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling RestapiApi->delFileByToken: ', $e->getMessage(), PHP_EOL;
}

// Configure API key authorization: ApiKeyAuth
$config = ATLS\Api\Configuration::getDefaultConfiguration()->setApiKey('X-ATRTS-API-Key', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = ATLS\Api\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-ATRTS-API-Key', 'Bearer');// Configure HTTP basic authorization: BasicAuth
$config = ATLS\Api\Configuration::getDefaultConfiguration()
    ->setUsername('YOUR_USERNAME')
    ->setPassword('YOUR_PASSWORD');

$apiInstance = new ATLS\Api\Api\RestapiApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$body = new \stdClass; // object | Example of a revised file request

try {
    $result = $apiInstance->getFileByToken($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling RestapiApi->getFileByToken: ', $e->getMessage(), PHP_EOL;
}

// Configure API key authorization: ApiKeyAuth
$config = ATLS\Api\Configuration::getDefaultConfiguration()->setApiKey('X-ATRTS-API-Key', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = ATLS\Api\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-ATRTS-API-Key', 'Bearer');// Configure HTTP basic authorization: BasicAuth
$config = ATLS\Api\Configuration::getDefaultConfiguration()
    ->setUsername('YOUR_USERNAME')
    ->setPassword('YOUR_PASSWORD');

$apiInstance = new ATLS\Api\Api\RestapiApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$projectid = 56; // int | Translation project identifier.
$sourcelang = "sourcelang_example"; // string | Source language code in ISO-639-3 format.
$targetlang = "targetlang_example"; // string | Target language code in ISO-639-3 format.
$datecutoff = "datecutoff_example"; // string | Cut-off date, in the following format: YYYYY-MM-DDTHH:MI:SSZ (UTC or Zulu time).
$options = "options_example"; // string | JSON auxiliary options.

try {
    $result = $apiInstance->getList($projectid, $sourcelang, $targetlang, $datecutoff, $options);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling RestapiApi->getList: ', $e->getMessage(), PHP_EOL;
}

// Configure API key authorization: ApiKeyAuth
$config = ATLS\Api\Configuration::getDefaultConfiguration()->setApiKey('X-ATRTS-API-Key', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = ATLS\Api\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-ATRTS-API-Key', 'Bearer');// Configure HTTP basic authorization: BasicAuth
$config = ATLS\Api\Configuration::getDefaultConfiguration()
    ->setUsername('YOUR_USERNAME')
    ->setPassword('YOUR_PASSWORD');

$apiInstance = new ATLS\Api\Api\RestapiApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$projectid = 56; // int | Translation project identifier.
$token = "token_example"; // string | Token resulting from the asynchronous translation request.
$options = "options_example"; // string | JSON auxiliary options.

try {
    $result = $apiInstance->getgetFileByToken($projectid, $token, $options);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling RestapiApi->getgetFileByToken: ', $e->getMessage(), PHP_EOL;
}

$apiInstance = new ATLS\Api\Api\RestapiApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client()
);

try {
    $result = $apiInstance->ping();
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling RestapiApi->ping: ', $e->getMessage(), PHP_EOL;
}

// Configure API key authorization: ApiKeyAuth
$config = ATLS\Api\Configuration::getDefaultConfiguration()->setApiKey('X-ATRTS-API-Key', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = ATLS\Api\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-ATRTS-API-Key', 'Bearer');// Configure HTTP basic authorization: BasicAuth
$config = ATLS\Api\Configuration::getDefaultConfiguration()
    ->setUsername('YOUR_USERNAME')
    ->setPassword('YOUR_PASSWORD');

$apiInstance = new ATLS\Api\Api\RestapiApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$body = new \stdClass; // object | Example of a revised translation

try {
    $result = $apiInstance->translateAsynchronous($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling RestapiApi->translateAsynchronous: ', $e->getMessage(), PHP_EOL;
}

// Configure API key authorization: ApiKeyAuth
$config = ATLS\Api\Configuration::getDefaultConfiguration()->setApiKey('X-ATRTS-API-Key', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = ATLS\Api\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-ATRTS-API-Key', 'Bearer');// Configure HTTP basic authorization: BasicAuth
$config = ATLS\Api\Configuration::getDefaultConfiguration()
    ->setUsername('YOUR_USERNAME')
    ->setPassword('YOUR_PASSWORD');

$apiInstance = new ATLS\Api\Api\RestapiApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$body = new \stdClass; // object | Example of synchronous machine translation

try {
    $result = $apiInstance->translateSynchronous($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling RestapiApi->translateSynchronous: ', $e->getMessage(), PHP_EOL;
}
?>
```

## Documentation for API Endpoints

All URIs are relative to *https://rts.at-ls.com/atrts*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*RestapiApi* | [**delFileByToken**](docs/Api/RestapiApi.md#delfilebytoken) | **POST** /delFileByToken | delFileByToken
*RestapiApi* | [**getFileByToken**](docs/Api/RestapiApi.md#getfilebytoken) | **POST** /getFileByToken | getFileByToken
*RestapiApi* | [**getList**](docs/Api/RestapiApi.md#getlist) | **GET** /getList | getList
*RestapiApi* | [**getgetFileByToken**](docs/Api/RestapiApi.md#getgetfilebytoken) | **GET** /getFileByToken | getFileByToken
*RestapiApi* | [**ping**](docs/Api/RestapiApi.md#ping) | **GET** /ping | ping
*RestapiApi* | [**translateAsynchronous**](docs/Api/RestapiApi.md#translateasynchronous) | **POST** /translateAsynchronous | translateAsynchronous
*RestapiApi* | [**translateSynchronous**](docs/Api/RestapiApi.md#translatesynchronous) | **POST** /translateSynchronous | translateSynchronous

## Documentation For Models

 - [ErrorResponse](docs/Model/ErrorResponse.md)
 - [File](docs/Model/File.md)
 - [InlineResponse200](docs/Model/InlineResponse200.md)
 - [InlineResponse401](docs/Model/InlineResponse401.md)
 - [InlineResponse405](docs/Model/InlineResponse405.md)
 - [InlineResponse503](docs/Model/InlineResponse503.md)
 - [OutFile](docs/Model/OutFile.md)
 - [OutList](docs/Model/OutList.md)
 - [OutToken](docs/Model/OutToken.md)

## Documentation For Authorization


## ApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-ATRTS-API-Key
- **Location**: HTTP header

## BasicAuth

- **Type**: HTTP basic authentication


## Author

info@at-ls.com

